pub struct ServerPost {
pub community: String,
pub title: String,
pub url: Option<String>,
pub body: Option<String>,
pub language: Option<String>,
pub alt_text: Option<String>,
pub nsfw: Option<bool>,
pub nsfl: Option<bool>,
pub ai_generated: Option<bool>,
pub custom_thumbnail: Option<String>,
}Expand description
A post that can be submitted to a fediverse service.
Fields
community: StringThe community to post to.
title: StringThe title of the post.
url: Option<String>An url to attach to the post. This can be a link to a website or an image.
body: Option<String>The body text of the post.
language: Option<String>The language of the post as a short language code, e.g. “en” for English.
alt_text: Option<String>The alt text of the attached url, if it is an image.
nsfw: Option<bool>Whether the post should be marked as NSFW (not safe for work).
nsfl: Option<bool>Whether the post should be marked as NSFL (not safe for life).
ai_generated: Option<bool>Whether the post is generated by A“I“ (artificial “intelligence”).
custom_thumbnail: Option<String>The thumbnail for the post. If not set, the service may fetch or generate one.